Module: kamailio
Branch: master
Commit: 621ba8bc1895e8b51e1eff6cbd32d391867d5c80
URL:
https://github.com/kamailio/kamailio/commit/621ba8bc1895e8b51e1eff6cbd32d39…
Author: Daniel-Constantin Mierla <miconda(a)gmail.com>
Committer: Daniel-Constantin Mierla <miconda(a)gmail.com>
Date: 2020-04-01T10:42:04+02:00
core: receive - reset xavu list after message processing
---
Modified: src/core/receive.c
---
Diff:
https://github.com/kamailio/kamailio/commit/621ba8bc1895e8b51e1eff6cbd32d39…
Patch:
https://github.com/kamailio/kamailio/commit/621ba8bc1895e8b51e1eff6cbd32d39…
---
diff --git a/src/core/receive.c b/src/core/receive.c
index 428214df68..1bf288420d 100644
--- a/src/core/receive.c
+++ b/src/core/receive.c
@@ -555,10 +555,11 @@ int receive_msg(char *buf, unsigned int len, receive_info_t
*rcv_info)
}
/**
* clean up msg environment, such as avp and xavp lists
*/
void ksr_msg_env_reset(void)
{
reset_avps();
xavp_reset_list();
+ xavu_reset_list();
}
@@ -555,10 +555,11 @@ int receive_msg(char *buf, unsigned int len, receive_info_t
}
/**
- * clean up msg environment, such as avp and xavp lists
+ * clean up msg environment, such as avp, xavp and xavu lists
*/
void ksr_msg_env_reset(void)